@@ -47,7 +47,7 @@ class Workspace(base.TogglEntity):
     rounding = fields.IntegerField()
     """
     Type of rounding:
-
+    
     * round down: -1
     * nearest: 0
     * round up: 1
@@ -60,7 +60,7 @@ class Workspace(base.TogglEntity):
 
     default_hourly_rate = fields.FloatField()
     """
-    Default hourly rate for workspace, won't be shown to non-admins
+    Default hourly rate for workspace, won't be shown to non-admins 
     if the only_admins_see_billable_rates flag is set to true
     """
 
@@ -163,23 +163,23 @@ class Project(WorkspacedEntity):
 
     billable = fields.BooleanField(premium=True)
     """
-    Whether the project is billable or not.
-
+    Whether the project is billable or not. 
+    
     (Available only for Premium workspaces)
     """
 
     auto_estimates = fields.BooleanField(default=False, premium=True)
     """
-    Whether the estimated hours are automatically calculated based on task estimations or manually
-    fixed based on the value of 'estimated_hours'.
-
+    Whether the estimated hours are automatically calculated based on task estimations or manually 
+    fixed based on the value of 'estimated_hours'. 
+    
     (Available only for Premium workspaces)
     """
 
-    estimated_hours = fields.IntegerField(default=0, premium=True)
+    estimated_hours = fields.IntegerField(premium=True)
     """
     If auto_estimates is true then the sum of task estimations is returned, otherwise user inserted hours.
-
+    
     (Available only for Premium workspaces)
     """
 
@@ -188,15 +188,10 @@ class Project(WorkspacedEntity):
     Id of the color selected for the project
     """
 
-    hex_color = fields.StringField()
-    """
-    Hex code of the color selected for the project
-    """
-
     rate = fields.FloatField(premium=True)
     """
     Hourly rate of the project.
-
+    
     (Available only for Premium workspaces)
     """
 
@@ -238,7 +233,7 @@ class User(WorkspacedEntity):
     api_token = fields.StringField()
     """
     API token to use for API calls.
-
+    
     (Returned only for User.objects.current_user() call.)
     """
 
@@ -247,7 +242,7 @@ class User(WorkspacedEntity):
     default_workspace = fields.MappingField(Workspace, 'default_wid')  # type: Workspace
     """
     Default workspace for calls that does not specify Workspace.
-
+    
     (Returned only for User.objects.current_user() call.)
     """
 
@@ -286,8 +281,8 @@ class User(WorkspacedEntity):
 
     timezone = fields.StringField()
     """
-    Timezone which is used to convert the times into.
-
+    Timezone which is used to convert the times into. 
+    
     May differ from one used in this tool, see toggl.utils.Config().
     """
 
@@ -374,7 +369,7 @@ class WorkspaceUser(WorkspacedEntity):
 
     admin = fields.BooleanField(admin_only=True)
     """
-    Weather user has admin privilege in the Workspace.
+    Weather user has admin privilege in the Workspace. 
     """
 
     user = fields.MappingField(User, 'uid', write=False)
@@ -398,13 +393,13 @@ class ProjectUser(WorkspacedEntity):
     rate = fields.FloatField(admin_only=True)
     """
     Hourly rate for the project user in the currency of the project's client or in workspace default currency.
-
+    
     (Available only for Premium workspaces)
     """
 
     manager = fields.BooleanField(default=False)
     """
-    Admin rights for this project
+    Admin rights for this project    
     """
 
     project = fields.MappingField(Project, 'pid', write=False)
@@ -502,7 +497,7 @@ def get_duration(name, instance):  # type: (str, base.Entity) -> int
     """
     Getter for Duration Property field.
 
-    Handles correctly the conversion of negative running duration (for more refer to the Toggl API doc).
+    Handles correctly the conversion of of negative running duration (for more refer to the Toggl API doc).
     """
     if instance.is_running:
         return instance.start.int_timestamp * -1
@@ -523,8 +518,6 @@ def set_duration(name, instance, value, init=False):  # type: (str, base.Entity,
     if value > 0:
         instance.is_running = False
         instance.stop = instance.start + pendulum.duration(seconds=value)
-    elif value == 0:
-        instance.is_running = False
     else:
         instance.is_running = True
         instance.stop = None
@@ -574,7 +567,7 @@ class TimeEntrySet(base.TogglSet):
 
         return url
 
-    def current(self, config=None):  # type: (utils.Config) -> typing.Optional[TimeEntry]
+    def current(self, config=None):  # type: (utils.Config) -> TimeEntry
         """
         Method that returns currently running TimeEntry or None if there is no currently running time entry.
 
@@ -603,7 +596,7 @@ class TimeEntrySet(base.TogglSet):
     def _should_fetch_more(self, page, returned):  # type: (int, typing.Dict) -> bool
         return page * returned['per_page'] < returned['total_count']
 
-    def _deserialize_from_reports(self, config, entity_dict, wid):
+    def _deserialize_from_reports(self, config, entity_dict):
         entity = {
             'id': entity_dict['id'],
             'start': entity_dict['start'],
@@ -613,8 +606,6 @@ class TimeEntrySet(base.TogglSet):
             'tags': entity_dict['tags'],
             'pid': entity_dict['pid'],
             'tid': entity_dict['tid'],
-            'uid': entity_dict['uid'],
-            'wid': wid,
             'billable': entity_dict['billable'],
         }
 
@@ -632,21 +623,15 @@ class TimeEntrySet(base.TogglSet):
         :return: Generator that yields TimeEntry
         """
         from .. import toggl
-
         config = config or utils.Config.factory()
         page = 1
 
-        if workspace is None:
-            wid = config.default_workspace.id
-        elif isinstance(workspace, Workspace):
+        try:
             wid = workspace.id
-        elif isinstance(workspace, int):
-            wid = workspace
-        else:
+        except AttributeError:
             try:
                 wid = int(workspace)
             except (ValueError, TypeError):
-                logger.exception("Couldn't infer workspace, falling back to default")
                 wid = config.default_workspace.id
 
         while True:
@@ -657,7 +642,7 @@ class TimeEntrySet(base.TogglSet):
                 return
 
             for entity in returned.get('data'):
-                yield self._deserialize_from_reports(config, entity, wid)
+                yield self._deserialize_from_reports(config, entity)
 
             if not self._should_fetch_more(page, returned):
                 return
@@ -686,7 +671,7 @@ class TimeEntry(WorkspacedEntity):
     billable = fields.BooleanField(default=False, premium=True)
     """
     If available to be billed. (Default: False)
-
+    
     (Available only for Premium workspaces)
     """
 
@@ -702,10 +687,10 @@ class TimeEntry(WorkspacedEntity):
 
     duration = fields.PropertyField(get_duration, set_duration, formatter=format_duration)
     """
-    Dynamic field of entry's duration in seconds.
-
-    If the time entry is currently running, the duration attribute contains a negative value,
-    denoting the start of the time entry in seconds since epoch (Jan 1 1970). The correct duration can be
+    Dynamic field of entry's duration in seconds. 
+    
+    If the time entry is currently running, the duration attribute contains a negative value, 
+    denoting the start of the time entry in seconds since epoch (Jan 1 1970). The correct duration can be 
     calculated as current_time + duration, where current_time is the current time in seconds since epoch.
     """
 
